@@ -36,6 +36,7 @@ sub phantom_ok {
       package => $opts->{package} || caller,
       no_exit => $opts->{no_exit},
       note_console => $opts->{note_console} // 1,
+      arguments => $opts->{phantom_args} // [],
     );
   };
 
@@ -199,7 +200,7 @@ A pass-through option specifying javascript to be run after the page object is c
 
 =item phantom
 
-If you need even more control, you may pass in an instance of L<Test::Mojo::Phantom> and it will be used.
+If you need even more control, you may pass in an instance of L<Mojo::Phantom> and it will be used.
 
 =item no_exit
 
@@ -210,6 +211,10 @@ Do not automatically call C<phantom.exit()> after the provided JavaScript code.
 Redirect C<console.log> output to TAP as note events.  This is usually helpful, but can be turned off if it becomes too
 verbose.
 
+=item phantom_args
+
+Specifies an array reference of command-line arguments passed directly to the PhantomJS process.
+
 =back
 
 =head1 DESIGN GOALS
